@@ -6,24 +6,30 @@ use overload
  '""'=>\&to_string,
  fallback=>1;
 
+
 use constant COMMON_RANGE=>0;
 use constant OVERLAP_RESULTS=>1;
 use constant OVERLAP_COUNT=>2;
 use constant OVERLAP_IDS=>3;
 use constant NON_OVERLAP_IDS=>4;
+use constant COLUMN_MAP=>5;
+use constant ROOT_IDS=>6;
+
 use constant PRINT_FORMAT=>'Commoon Range: [%s] Column id(s) that Overlap: [%s]';
 
-sub new {
-  my ($class,@args)=@_;
-  bless [@args],$class;
-}
+use base qw(Data::Range::Compare::Stream::Result::Base);
 
 sub get_common_range {
   my ($self)=@_;
   $self->[$self->COMMON_RANGE]
 }
+
 *get_common=\&get_common_range;
 
+sub get_root_ids { [@{$_[0]->[$_[0]->ROOT_IDS]}] }
+
+sub get_column_map { [@{$_[0]->[$_[0]->COLUMN_MAP]}] }
+
 sub get_overlap_count {
   my ($self)=@_;
   $self->[$self->OVERLAP_COUNT]
@@ -84,5 +90,47 @@ sub to_string {
   return sprintf $self->PRINT_FORMAT,$self->get_common,join(',',@{$self->get_overlap_ids});
 }
 
+sub get_root_result_ids {
+  my ($self)=@_;
+
+  my $result=[];
+
+  my $map=$self->[$self->COLUMN_MAP];
+
+  for(my $id=0;$id<$self->get_column_count;++$id ) {
+    my $target=$map->[$id];
+    $result->[$target]=[] unless defined($result->[$target]);
+
+    my $ref=$result->[$target];
+    my $obj=$self->get_result_by_id($id);
+
+    push @$ref,$id if defined($obj);
+  }
+
+  return $result;
+}
+
+sub get_root_results {
+  my ($self)=@_;
+
+  my $result=[];
+
+  my $map=$self->[$self->COLUMN_MAP];
+
+  for(my $id=0;$id<$self->get_column_count;++$id ) {
+    my $target=$map->[$id];
+    $result->[$target]=[] unless defined($result->[$target]);
+
+    my $ref=$result->[$target];
+    my $obj=$self->get_result_by_id($id);
+    next unless defined($obj);
+
+    push @$ref,$obj;
+  }
+
+  return $result;
+}
+
+
 
 1;
